@@ -16,12 +16,15 @@
 */
 
 #include "suil_internal.h"
+#include "warnings.h"
 
 #include "lv2/options/options.h"
 #include "lv2/urid/urid.h"
 
+SUIL_DISABLE_GTK_WARNINGS
 #include <gdk/gdkquartz.h>
 #include <gtk/gtk.h>
+SUIL_RESTORE_WARNINGS
 
 #include <string.h>
 
